Class: Google::Apis::MybusinessaccountmanagementV1::TargetLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinessaccountmanagement_v1/classes.rb,
lib/google/apis/mybusinessaccountmanagement_v1/representations.rb,
lib/google/apis/mybusinessaccountmanagement_v1/representations.rb

Overview

Represents a target location for a pending invitation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetLocation

Returns a new instance of TargetLocation.



534
535
536
# File 'lib/google/apis/mybusinessaccountmanagement_v1/classes.rb', line 534

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

The address of the location to which the user is invited. Not always populated. Corresponds to the JSON property address

Returns:

  • (String)


527
528
529
# File 'lib/google/apis/mybusinessaccountmanagement_v1/classes.rb', line 527

def address
  @address
end

#location_nameString

The name of the location to which the user is invited. Corresponds to the JSON property locationName

Returns:

  • (String)


532
533
534
# File 'lib/google/apis/mybusinessaccountmanagement_v1/classes.rb', line 532

def location_name
  @location_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



539
540
541
542
# File 'lib/google/apis/mybusinessaccountmanagement_v1/classes.rb', line 539

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @location_name = args[:location_name] if args.key?(:location_name)
end