Class: Google::Apis::MybusinessaccountmanagementV1::OrganizationInfo
- Inherits:
-
Object
- Object
- Google::Apis::MybusinessaccountmanagementV1::OrganizationInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinessaccountmanagement_v1/classes.rb,
lib/google/apis/mybusinessaccountmanagement_v1/representations.rb,
lib/google/apis/mybusinessaccountmanagement_v1/representations.rb
Overview
Additional information stored for an organization.
Instance Attribute Summary collapse
-
#address ⇒ Google::Apis::MybusinessaccountmanagementV1::PostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
-
#phone_number ⇒ String
Output only.
-
#registered_domain ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrganizationInfo
constructor
A new instance of OrganizationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrganizationInfo
Returns a new instance of OrganizationInfo.
373 374 375 |
# File 'lib/google/apis/mybusinessaccountmanagement_v1/classes.rb', line 373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Google::Apis::MybusinessaccountmanagementV1::PostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
With a postal address, a postal service can deliver items to a premise, P.O.
box, or similar. A postal address is not intended to model geographical
locations like roads, towns, or mountains. In typical usage, an address would
be created by user input or from importing existing data, depending on the
type of process. Advice on address input or editing: - Use an
internationalization-ready address widget such as https://github.com/google/
libaddressinput. - Users should not be presented with UI elements for input or
editing of fields outside countries where that field is used. For more
guidance on how to use this schema, see: https://support.google.com/business/
answer/6397478.
Corresponds to the JSON property address
361 362 363 |
# File 'lib/google/apis/mybusinessaccountmanagement_v1/classes.rb', line 361 def address @address end |
#phone_number ⇒ String
Output only. The contact number for the organization.
Corresponds to the JSON property phoneNumber
366 367 368 |
# File 'lib/google/apis/mybusinessaccountmanagement_v1/classes.rb', line 366 def phone_number @phone_number end |
#registered_domain ⇒ String
Output only. The registered domain for the account.
Corresponds to the JSON property registeredDomain
371 372 373 |
# File 'lib/google/apis/mybusinessaccountmanagement_v1/classes.rb', line 371 def registered_domain @registered_domain end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
378 379 380 381 382 |
# File 'lib/google/apis/mybusinessaccountmanagement_v1/classes.rb', line 378 def update!(**args) @address = args[:address] if args.key?(:address) @phone_number = args[:phone_number] if args.key?(:phone_number) @registered_domain = args[:registered_domain] if args.key?(:registered_domain) end |